package com.yanzuoguang.util.log;

import java.util.Date;

/**
 * 日志实体记录类
 * @author 颜佐光
 */
public class LogInfo {
    /**
     * 触发类
     */
    private Class<?> cls;
    /**
     * 错误发生时间
     */
    private long now;
    /**
     * 标记信息
     */
    private String tag = "";
    /**
     * 日志内容
     */
    private String message;
    /**
     * 日志异常信息
     */
    private Throwable exception;
    /**
     * 上次到这次的执行完成的时间
     */
    private long time;
    /**
     * 总时间
     */
    private long totalTime;

    /**
     * 构造函数
     *
     * @param msg 日志消息
     */
    public LogInfo(String msg) {
        this(new Date(), null, msg);
    }

    /**
     * 构造函数
     *
     * @param ex 异常信息
     */
    public LogInfo(Exception ex) {
        this(new Date(), ex, "");
    }

    /**
     * 日志信息
     *
     * @param date 时间
     * @param ex   异常信息
     */
    public LogInfo(Date date, Exception ex) {
        this(date, ex, "");
    }

    /**
     * 构造函数
     *
     * @param date 时间
     * @param msg  消息
     */
    public LogInfo(Date date, String msg) {
        this(date, null, msg);
    }

    /**
     * 构造函数
     *
     * @param date 时间
     * @param ex   异常
     * @param msg  消息
     */
    public LogInfo(Date date, Throwable ex, String msg) {
        this(null, date, ex, msg);
    }

    /**
     * 构造函数
     *
     * @param cls  触发类
     * @param date 时间
     * @param ex   异常
     * @param msg  消息
     */
    public LogInfo(Class<?> cls, Date date, Throwable ex, String msg) {
        this.cls = cls;
        this.setNow(date);
        this.setException(ex);
        this.setMessage(msg);
    }

    public Class<?> getCls() {
        return cls;
    }

    public void setCls(Class<?> cls) {
        this.cls = cls;
    }

    public Date getNow() {
        if(this.now == 0){
            return null;
        }
        else{
            return new Date(this.now);
        }
    }

    public void setNow(Date now) {
        if(now != null){
            this.now = now.getTime() ;
        }
        else{
            this.now = 0;
        }
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public Throwable getException() {
        return exception;
    }

    public void setException(Throwable exception) {
        this.exception = exception;
    }

    public long getTime() {
        return time;
    }

    public void setTime(long time) {
        this.time = time;
    }

    public long getTotalTime() {
        return totalTime;
    }

    public void setTotalTime(long totalTime) {
        this.totalTime = totalTime;
    }
}
